@@ -8,15 +8,18 @@ import stretch_body.hello_utils as hu
 hu.print_stretch_re_use()
 
 parser=argparse.ArgumentParser(description='Jog the arm motion from the keyboard')
+parser.add_argument("--no_rs", help="No runstop required",action="store_true")
 args=parser.parse_args()
 
 small_move_m=.01
 large_move_m=0.1
 
 a=arm.Arm()
-if not a.startup():
+if not a.startup(threaded=False):
     exit()
 a.motor.disable_sync_mode()
+if args.no_rs:
+    a.motor.disable_runstop()
 a.push_command()
 
 def get_keystroke():
